==> cutetube_1.7.7.tar.gz: cutetube-1.7.7/cutetubeevents/src/event.h <==
#ifndef EVENT_H
#define EVENT_H

#include <QString>

class Event {

public:
    explicit Event() {}
    inline QString id() const { return m_id; }
    inline void setId(const QString &id) { m_id = id; }
    inline QString sourceName() const { return m_sourceName; }
    inline void setSourceName(const QString &name) { m_sourceName = name; }
    inline QString sourceDisplayName() const { return m_sourceDisplayName; }
    inline void setSourceDisplayName(const QString &name) { m_sourceDisplayName = name; }
    inline QString iconPath() const { return m_iconPath; }
    inline void setIconPath(const QString &path) { m_iconPath = path; }
    inline QString title() const { return m_title; }
    inline void setTitle(const QString &title) { m_title = title; }
    inline QString body() const { return m_body; }
    inline void setBody(const QString &body) { m_body = body; }
    inline QString imagePathOne() const { return m_imagePathOne; }
    inline void setImagePathOne(const QString &path) { m_imagePathOne = path; }
    inline QString imagePathTwo() const { return m_imagePathTwo; }
    inline void setImagePathTwo(const QString &path) { m_imagePathTwo = path; }
    inline QString footer() const { return m_footer; }
    inline void setFooter(const QString &footer) { m_footer = footer; }
    inline QString timestamp() const { return m_timestamp; }
    inline void setTimestamp(const QString &timestamp) { m_timestamp = timestamp; }
    inline QString action() const { return m_action; }
    inline void setAction(const QString &action) { m_action = action; }

private:
    QString m_id;
    QString m_sourceName;
    QString m_sourceDisplayName;
    QString m_iconPath;
    QString m_title;
    QString m_body;
    QString m_imagePathOne;
    QString m_imagePathTwo;
    QString m_footer;
    QString m_timestamp;
    QString m_action;
};

#endif // EVENT_H

==> cutetube_1.9.1.tar.gz: cutetube-1.9.1/cutetubeevents/src/event.h <==
#ifndef EVENT_H
#define EVENT_H

#include <QString>

class Event {

public:
    explicit Event() {}
    inline QString id() const { return m_id; }
    inline void setId(const QString &id) { m_id = id; }
    inline QString url() const { return m_url; }
    inline void setUrl(const QString &url) { m_url = url; }
    inline QString sourceName() const { return m_sourceName; }
    inline void setSourceName(const QString &name) { m_sourceName = name; }
    inline QString sourceDisplayName() const { return m_sourceDisplayName; }
    inline void setSourceDisplayName(const QString &name) { m_sourceDisplayName = name; }
    inline QString iconPath() const { return m_iconPath; }
    inline void setIconPath(const QString &path) { m_iconPath = path; }
    inline QString title() const { return m_title; }
    inline void setTitle(const QString &title) { m_title = title; }
    inline QString body() const { return m_body; }
    inline void setBody(const QString &body) { m_body = body; }
    inline QString imagePathOne() const { return m_imagePathOne; }
    inline void setImagePathOne(const QString &path) { m_imagePathOne = path; }
    inline QString imagePathTwo() const { return m_imagePathTwo; }
    inline void setImagePathTwo(const QString &path) { m_imagePathTwo = path; }
    inline QString footer() const { return m_footer; }
    inline void setFooter(const QString &footer) { m_footer = footer; }
    inline QString timestamp() const { return m_timestamp; }
    inline void setTimestamp(const QString &timestamp) { m_timestamp = timestamp; }
    inline QString action() const { return m_action; }
    inline void setAction(const QString &action) { m_action = action; }

private:
    QString m_id;
    QString m_url;
    QString m_sourceName;
    QString m_sourceDisplayName;
    QString m_iconPath;
    QString m_title;
    QString m_body;
    QString m_imagePathOne;
    QString m_imagePathTwo;
    QString m_footer;
    QString m_timestamp;
    QString m_action;
};

#endif // EVENT_H
